/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * http//www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is ART OWL API.
 *
 * The Initial Developer of the Original Code is University of Roma Tor Vergata.
 * Portions created by University of Roma Tor Vergata are Copyright (C) 2009.
 * All Rights Reserved.
 *
 * The ART OWL API were developed by the Artificial Intelligence Research Group
 * (art.uniroma2.it) at the University of Roma Tor Vergata
 * Current information about the ART OWL API can be obtained at 
 * http://art.uniroma2.it/owlart
 *
 */

package it.uniroma2.art.owlart.io;

import java.io.File;
import java.util.HashMap;

/**
 * container class for the various RDF serialization formats currently standardized by the W3C
 * 
 * @author Armando Stellato
 *
 */
public class RDFFormat {

	private static HashMap<String, RDFFormat> fileExtToFormatsMap;
	private static HashMap<String, RDFFormat> namesToFormatsMap;

	public static RDFFormat RDFXML;
	public static RDFFormat RDFXML_ABBREV;
	public static RDFFormat NTRIPLES;
	public static RDFFormat N3;
	public static RDFFormat TRIG;
	public static RDFFormat TRIX;
	public static RDFFormat TRIXEXT;
	public static RDFFormat TURTLE;

	static {

		RDFXML = new RDFFormat("RDF/XML");
		RDFXML_ABBREV = new RDFFormat("RDF/XML-ABBREV");
		NTRIPLES = new RDFFormat("N-TRIPLES");
		N3 = new RDFFormat("N3");
		TRIG = new RDFFormat("TRIG");
		TRIX = new RDFFormat("TRIX");
		TRIXEXT = new RDFFormat("TRIX-EXT");
		TURTLE = new RDFFormat("TURTLE");

		fileExtToFormatsMap = new HashMap<String, RDFFormat>();

		fileExtToFormatsMap.put("xml", RDFXML);
		fileExtToFormatsMap.put("rdf", RDFXML);
		fileExtToFormatsMap.put("rdfs", RDFXML);
		fileExtToFormatsMap.put("owl", RDFXML);
		fileExtToFormatsMap.put("nt", NTRIPLES);
		fileExtToFormatsMap.put("n3", N3);
		fileExtToFormatsMap.put("trig", TRIG);
		fileExtToFormatsMap.put("trix", TRIX);
		fileExtToFormatsMap.put("trix-ext", TRIXEXT);
		fileExtToFormatsMap.put("ttl", TURTLE);
		
		namesToFormatsMap = new HashMap<String, RDFFormat>();
		
		namesToFormatsMap.put(RDFXML.getName(), RDFXML);
		namesToFormatsMap.put(RDFXML_ABBREV.getName(), RDFXML_ABBREV);
		namesToFormatsMap.put(NTRIPLES.getName(), NTRIPLES);
		namesToFormatsMap.put(N3.getName(), N3);
		namesToFormatsMap.put(TRIG.getName(), TRIG);
		namesToFormatsMap.put(TRIX.getName(), TRIX);
		namesToFormatsMap.put(TRIXEXT.getName(), TRIXEXT);
		namesToFormatsMap.put(TURTLE.getName(), TURTLE);
		
		
	}

	private String formatName;

	private RDFFormat(String name) {
		formatName = name;
	}

	public String getName() {
		return formatName;
	}

	public static RDFFormat guessRDFFormatFromFile(File file) {
		String filename = file.toString();
		String ext = (filename.lastIndexOf(".") == -1) ? "" : filename.substring(
				filename.lastIndexOf(".") + 1, filename.length());
		return fileExtToFormatsMap.get(ext);
	}

	public static RDFFormat parseFormat(String formatName) {
		return namesToFormatsMap.get(formatName);
	}
	
	public String toString() {
		return formatName;
	}
	
}
