/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * http//www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is ART OWL API.
 *
 * The Initial Developer of the Original Code is University of Roma Tor Vergata.
 * Portions created by University of Roma Tor Vergata are Copyright (C) 2009.
 * All Rights Reserved.
 *
 * The ART OWL API were developed by the Artificial Intelligence Research Group
 * (art.uniroma2.it) at the University of Roma Tor Vergata
 * Current information about the ART OWL API can be obtained at 
 * http://art.uniroma2.it/owlart
 *
 */

package it.uniroma2.art.owlart.utilities;

import java.util.ArrayList;
import java.util.Collection;

import it.uniroma2.art.owlart.exceptions.ModelAccessException;
import it.uniroma2.art.owlart.navigation.RDFIterator;

/**
 * Utility methods for managing {@link RDFIterator}s
 * 
 * @author Armando Stellato
 *
 */
public class RDFIterators {

	/**
	 * this method obtains a collection of objects extracted from an {@link RDFIterator}. Note that the
	 * RDFIterator is automatically closed at the end of execution of this method
	 * 
	 * @param <T>
	 * @param rdfIt
	 * @return
	 * @throws ModelAccessException
	 */
	public static <T> Collection<T> getCollectionFromIterator(RDFIterator<T> rdfIt)
			throws ModelAccessException {
		ArrayList<T> collection = new ArrayList<T>();
		while (rdfIt.streamOpen()) {
			collection.add(rdfIt.getNext());
		}
		rdfIt.close();
		return collection;
	}

}
